CREATE TABLE Books

(

ID_Book int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Book),

Reference varchar(255),

Quality varchar(255),

Quality_Number int,

Author varchar(255),

Title varchar(255),

Publisher_Info varchar(255),

Notes varchar(255),

Year_Published int unsigned

);



CREATE TABLE Commodity

(

ID_Commodity int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Commodity),

Commodity varchar(255)

);



CREATE TABLE Market

(

ID_Market int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Market),

Market varchar(255),

Latitude DECIMAL(9,9),

Longtitude DECIMAL(9,9),

Alternative_Names varchar(255)

);



CREATE TABLE Notes

(

ID_Notes int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Notes),

Notes varchar(255)

);



CREATE TABLE Sources

(

ID_Source int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Source),

Reference2 varchar(255),

Reference3 varchar(255),

Reference4 varchar(255),

Reference5 varchar(255),

Source_Raw varchar(255)

);



CREATE TABLE Variety

(

ID_Variety int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Variety),

Variety varchar(255)

);



CREATE TABLE Currency_Sets

(

ID_Currency_Sets int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Currency_Sets),

Currency_Sources_ID int UNSIGNED NOT NULL REFERENCES Currency_Sources(ID_Currency_Sources),

Conversion_Type varchar(255),

Conversion_Measure varchar(255)

);



CREATE TABLE Currency_Sources

(

ID_Currency_Sources int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Currency_Sources),

Currency_Type_ID int UNSIGNED NOT NULL REFERENCES Currency_Type(ID_Currency_Type ),

Notes_ID int UNSIGNED NOT NULL REFERENCES Notes(ID_Notes),

Source_ID int UNSIGNED NOT NULL REFERENCES Sources(ID_Source)

);



CREATE TABLE Currency_Items

(

ID_Currency_Items int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Currency_Items),

Currency_Sets_ID int UNSIGNED NOT NULL REFERENCES Currency_Sets(ID_Currency_Sets),

Currency_Item_Year int unsigned,

Currency_Item_Value DECIMAL(9,9)

);



CREATE TABLE Currency_Type

(

ID_Currency_Type int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Currency_Type),

Market_ID int UNSIGNED NOT NULL REFERENCES Market(ID_Market),

Currency_Name_Common varchar(255),

Currency_Family varchar(255),

Currency_SubType varchar(255)

);



CREATE TABLE GCPdb_Sets

(

ID_GCPdb_Sets int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_GCPdb_Sets),

GCPdb_Sources_ID int UNSIGNED NOT NULL REFERENCES GCPdb_Sources(ID_GCPdb_Sources),

Currency_ID_Original int UNSIGNED NOT NULL REFERENCES Currency_Type(ID_Currency_Type),

Measures_ID_Original int UNSIGNED NOT NULL REFERENCES Measures(ID_Measures),

Currency_ID_Standardized int UNSIGNED NOT NULL REFERENCES Currency_Type(ID_Currency_Type),

Measures_ID_Standardized int UNSIGNED NOT NULL REFERENCES Measures(ID_Measures),

False_ID_Construct int

);



CREATE TABLE GCPdb_Sources

(

ID_GCPdb_Sources int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_GCPdb_Sources),

GCPdb_Type_ID int UNSIGNED NOT NULL REFERENCES GCPdb_Type(ID_GCPdb_Type),

Source_ID int UNSIGNED NOT NULL REFERENCES Sources(ID_Source),

Notes_ID int UNSIGNED NOT NULL REFERENCES Notes(ID_Notes),

False_ID_Construct int

);



CREATE TABLE GCPdb_Type

(

ID_GCPdb_Type int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_GCPdb_Type),

Type_ID int,

Market_ID int UNSIGNED NOT NULL REFERENCES Market(ID_Market),

Commodity_ID int UNSIGNED NOT NULL REFERENCES Commodity(ID_Commodity),

Variety_ID int UNSIGNED NOT NULL REFERENCES Variety(ID_Variety)

);



CREATE TABLE GCPdb_Items

(

ID_GCPdb_Item int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_GCPdb_Item),

GCPdb_Sets_ID int UNSIGNED NOT NULL REFERENCES GCPdb_Sets(ID_GCPdb_Sets),

Item_Years int unsigned,

Item_Value_Standardized DECIMAL(9,9),

Item_Value_Original DECIMAL(9,9)

);



CREATE TABLE Measures

(

ID_Measures int unsigned NOT NULL AUTO_INCREMENT,

PRIMARY KEY(ID_Measures),

Measure_Family varchar(255),

Measure_SubType varchar(255),

Markets_ID int UNSIGNED NOT NULL REFERENCES Market(ID_Market),

Measure_Name varchar(255),

Alternative_Name varchar(255),

Conversion_Factor DECIMAL(9,9),

Conversion_Unit varchar(255),

Conversion_Type varchar(255),

Conversion_SubType varchar(255),

Source_ID int UNSIGNED NOT NULL REFERENCES Sources(ID_Source),

Date_Start int unsigned,

Date_End int unsigned

);



CREATE VIEW View_GCPdb AS 

SELECT Commodity.Commodity, 

       Variety.Variety, 

	   Market.Market, 

	   Measures.Measure_Name AS Measure_Original, 

	   Measures_1.Measure_Name AS Measure_Standardized, 

	   Currency_Type.Currency_Name_Common AS Currency_Original, 

	   Currency_Type_1.Currency_Name_Common AS Currency_Standardized, 

	   GCPdb_Items.Item_Years, 

	   GCPdb_Items.Item_Value_Original, 

	   GCPdb_Items.Item_Value_Standardized, 

	   Notes.Notes AS Item_Notes, 

	   Sources.Source_Raw AS Item_Sources

FROM Variety 

	INNER JOIN (Sources 

	INNER JOIN (Notes 

	INNER JOIN (Measures 

	INNER JOIN (Market 

	INNER JOIN ((Commodity 

	INNER JOIN GCPdb_Type

	  ON Commodity.ID_Commodity = GCPdb_Type.Commodity_ID) 

	INNER JOIN (GCPdb_Sources 

	INNER JOIN ((Currency_Type 

	INNER JOIN (Currency_Type AS Currency_Type_1 

	INNER JOIN (Measures AS Measures_1 

	INNER JOIN GCPdb_Sets 

	  ON Measures_1.ID_Measures = GCPdb_Sets.Measures_ID_Standardized) 

	  ON Currency_Type_1.ID_Currency_Type = GCPdb_Sets.Currency_ID_Standardized) 

	  ON Currency_Type.ID_Currency_Type = GCPdb_Sets.Currency_ID_Original) 

	INNER JOIN GCPdb_Items 

	  ON GCPdb_Sets.ID_GCPdb_Sets = GCPdb_Items.GCPdb_Sets_ID) 

	  ON GCPdb_Sources.ID_GCPdb_Sources = GCPdb_Sets.GCPdb_Sources_ID) 

	  ON GCPdb_Type.ID_GCPdb_Type = GCPdb_Sources.GCPdb_Type_ID) 

	  ON Market.ID_Market = GCPdb_Type.Market_ID) 

	  ON Measures.ID_Measures = GCPdb_Sets.Measures_ID_Original) 

	  ON Notes.ID_Notes = GCPdb_Sources.Notes_ID) 

	  ON Sources.ID_Source = GCPdb_Sources.Source_ID) 

	  ON Variety.ID_Variety = GCPdb_Type.Variety_ID 

ORDER BY Commodity.Commodity, 

         Market.Market;



CREATE VIEW View_Currency AS 

SELECT Market.Market as Currency_Market, 

       Currency_Type.

	   Currency_Family, 

	   Currency_Type.Currency_SubType, 

	   Currency_Type.Currency_Name_Common, 

	   Currency_Items.Currency_Item_Year, 

	   Currency_Items.Currency_Item_Value, 

	   Currency_Sets.Conversion_Measure, 

	   Currency_Sets.Conversion_Type, 

	   Notes.Notes as Currency_Item_Notes, 

	   Sources.Source_Raw as Currency_Item_Sources

FROM 

Sources INNER JOIN 

  (Notes INNER JOIN 

    (Market INNER JOIN 

      (Currency_Type INNER JOIN 

        (Currency_Sources INNER JOIN 

          (Currency_Sets INNER JOIN 

		    Currency_Items 

		   ON Currency_Sets.ID_Currency_Sets = Currency_Items.Currency_Sets_ID) 

         ON Currency_Sources.ID_Currency_Sources = Currency_Sets.Currency_Sources_ID) 

        ON Currency_Type.ID_Currency_Type = Currency_Sources.Currency_Type_ID) 

      ON Market.ID_Market = Currency_Type.Market_ID) 

	ON Notes.ID_Notes = Currency_Sources.Notes_ID) 

  ON Sources.ID_Source = Currency_Sources.Source_ID

ORDER BY Market.Market, Currency_Type.Currency_Name_Common, Currency_Items.Currency_Item_Year;





CREATE VIEW View_Commodiy_Market AS 

SELECT Market.Market, 

       Commodity.Commodity, 

	   Variety.Variety

FROM Variety 

  INNER JOIN (Market 

  INNER JOIN (Commodity 

  INNER JOIN GCPdb_Type 

    ON Commodity.ID_Commodity = GCPdb_Type.Commodity_ID) 

	ON Market.ID_Market = GCPdb_Type.Market_ID) 

	ON Variety.ID_Variety = GCPdb_Type.Variety_ID

GROUP BY Market.Market, 

         Commodity.Commodity, 

		 Variety.Variety

ORDER BY Market.Market;





CREATE VIEW View_Market_Commodiy AS 

SELECT Commodity.Commodity, 

       Variety.Variety, 

	   Market.Market

FROM Variety 

  INNER JOIN (Market 

  INNER JOIN (Commodity 

  INNER JOIN GCPdb_Type 

    ON Commodity.ID_Commodity = GCPdb_Type.Commodity_ID) 

	ON Market.ID_Market = GCPdb_Type.Market_ID) 

	ON Variety.ID_Variety = GCPdb_Type.Variety_ID

GROUP BY Commodity.Commodity, 

         Variety.Variety, 

		 Market.Market

ORDER BY Commodity.Commodity,

         Variety.Variety, 

		 Market.Market;



CREATE VIEW View_Markets AS 

SELECT Market.Market, 

       Market.Latitude, 

	   Market.Longtitude, 

	   Market.Alternative_Names

FROM Market 

  INNER JOIN (Commodity 

  INNER JOIN GCPdb_Type 

    ON Commodity.ID_Commodity = GCPdb_Type.Commodity_ID) 

	ON Market.ID_Market = GCPdb_Type.Market_ID

GROUP BY Market.Market, 

         Market.Latitude, 

		 Market.Longtitude, 

		 Market.Alternative_Names

ORDER BY Market.Market;



CREATE VIEW View_Measures AS 

SELECT Measures.Measure_Name, 

       Measures.Measure_Family, 

	   Measures.Measure_SubType, 

	   Market.Market as Measure_Market, 

	   Measures.Conversion_Factor AS Factor, 

	   Measures.Conversion_Unit AS Units, 

	   Measures.Conversion_Type, 

	   Measures.Conversion_SubType, 

	   Measures.Date_Start, 

	   Measures.Date_End, 

	   Measures.Alternative_Name, 

	   Sources.Source_Raw

FROM Sources 

  INNER JOIN (Market 

  INNER JOIN Measures ON Market.ID_Market = Measures.Markets_ID) 

    ON Sources.ID_Source = Measures.Source_ID

ORDER BY Measures.Measure_Family, 

         Measures.Measure_SubType;



CREATE VIEW XML_Map AS 

SELECT Market.Market, 

       Market.Latitude, 

	   Market.Longtitude, 

	   Market.Alternative_Names, 

	   Commodity.Commodity, 

	   Variety.Variety

FROM Variety 

  INNER JOIN (Market 

  INNER JOIN (Commodity 

  INNER JOIN GCPdb_Type 

    ON Commodity.ID_Commodity = GCPdb_Type.Commodity_ID) 

	ON Market.ID_Market = GCPdb_Type.Market_ID) 

	ON Variety.ID_Variety = GCPdb_Type.Variety_ID

GROUP BY Market.Market, 

         Market.Latitude, 

		 Market.Longtitude, 

		 Market.Alternative_Names, 

		 Commodity.Commodity, 

		 Variety.Variety

ORDER BY Market.Market;









